Learn R Programming

teal (version 1.2.1)

.copy_to_teal: Copy functions to teal namespace

Description

Useful when we require function from other namespace where this function calls other functions from teal namespace (see as.teal_slices, c.teal_slices).

Usage

.copy_to_teal(fun)

Arguments