FilteredData to reactive list of datasets of the teal_data type.Converts FilteredData object to teal_data object containing datasets needed for a specific module.
Please note that if a module needs a dataset which has a parent, then the parent will also be returned.
A hash per dataset is calculated internally and returned in the code.
.datasets_to_data(module, datasets)A teal_data object.
(teal_module) module where needed filters are taken from
(FilteredData) object where needed data are taken from