View source: R/module_teal_reporter.R
| disable_report | R Documentation |
teal_moduleConvenience function that disables the user's ability to add the module to the report previewer.
disable_report(x)
x |
( |
modified data object that indicates that it should disable the reporter functionality.
disable_src()
# Disabling report on a single module
app <- init(
data = within(teal_data(), iris <- iris),
modules = modules(
example_module(label = "example teal module") |> disable_report()
)
)
if (interactive()) {
shinyApp(app$ui, app$server)
}
# Disabling report on multiple modules
app <- init(
data = within(teal_data(), iris <- iris),
modules = modules(
example_module(label = "example 1"),
example_module(label = "example 2")
) |> disable_report()
)
if (interactive()) {
shinyApp(app$ui, app$server)
}
# Disabling reporting for the app
app <- init(
data = within(teal_data(), iris <- iris),
modules = modules(
example_module(label = "example teal module")
),
reporter = NULL
)
if (interactive()) {
shinyApp(app$ui, app$server)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.