dot-add_signature_to_data: Adds signature protection to the 'datanames' in the data

.add_signature_to_dataR Documentation

Adds signature protection to the datanames in the data

Description

Adds signature protection to the datanames in the data

Usage

.add_signature_to_data(data)

Arguments

data

(teal_data)

Value

teal_data with additional code that has signature of the datanames


teal documentation built on June 30, 2026, 5:11 p.m.