dot-copy_to_teal: Copy functions to 'teal' namespace

.copy_to_tealR Documentation

Copy functions to teal namespace

Description

Useful when we require function from other namespace where this function calls other functions from teal namespace (see as.teal_slices, c.teal_slices).

Usage

.copy_to_teal(fun)

teal documentation built on June 30, 2026, 5:11 p.m.