dot-get_hashes_code: Get code that tests the integrity of the reproducible data

.get_hashes_codeR Documentation

Get code that tests the integrity of the reproducible data

Description

Get code that tests the integrity of the reproducible data

Usage

.get_hashes_code(data, datanames = names(data))

Arguments

data

(teal_data) object holding the data

datanames

(character) names of datasets

Value

A character vector with the code lines.


teal documentation built on June 30, 2026, 5:11 p.m.