View source: R/dummy_functions.R
| example_module | R Documentation |
teal moduleThis module creates an object called object that can be modified with decorators.
The object is determined by what's selected in Choose a dataset input in UI.
The object can be anything that can be handled by renderPrint().
See the vignette("transform-module-output", package = "teal") or teal_transform_module
to read more about decorators.
example_module(
label = "example teal module",
datanames = "all",
transformators = list(),
decorators = list()
)
A teal module which can be included in the modules argument to init().
This module returns an object of class teal_module, that contains a server function.
Since the server function returns a teal_report object, this makes this module reportable, which means that
the reporting functionality will be turned on automatically by the teal framework.
For more information on reporting in teal, see the vignettes:
vignette("reportable-shiny-application", package = "teal.reporter")
vignette("adding-support-for-reporting-to-custom-modules", package = "teal")
app <- init(
data = teal_data(IRIS = iris, MTCARS = mtcars),
modules = example_module()
)
if (interactive()) {
shinyApp(app$ui, app$server)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.