teal-package: 'teal': Interactive exploration of clinical trials data

teal-packageR Documentation

teal: Interactive exploration of clinical trials data

Description

The teal package provides a shiny based framework for creating an interactive data analysis environment.

Details

To learn mode about the package, visit the project website or read the init() manual page.

Author(s)

Maintainer: Dony Unardi unardid@gene.com

Authors:

Other contributors:

  • Nina Qi qi.ting@gene.com [reviewer]

  • Chendi Liao [reviewer]

  • F. Hoffmann-La Roche AG [copyright holder, funder]

  • Maximilian Mordig [contributor]

See Also

Useful links:


teal documentation built on June 30, 2026, 5:11 p.m.