| after | R Documentation |
Exported to be able to use methods not to be used directly by module-developers or app-users. Primarily used to modify the output object of module.
after(x, server = function(input, output, session, data) data, ...)
x |
( |
server |
( |
... |
Additional arguments passed to the server wrapper function by matching their formal names. |
A teal_module or teal_modules object with a wrapped server.
disable_src(), disable_report()
library("teal.reporter")
hide_code <- function(input, output, session, data) {
teal_card(data) <- Filter(function(x) !inherits(x, "code_chunk"), teal_card(data))
data
}
app <- init(
data = teal_data(IRIS = iris, MTCARS = mtcars),
modules = example_module() |>
after(server = hide_code)
)
if (interactive()) {
runApp(app)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.