| module_transform_teal_data_impl | R Documentation |
teal_transform_module()This module calls teal_transform_module() sequentially by passing output from one step to the next.
Modules have error/warning handling feature and highlight containers when something goes wrong.
.ui_transform_teal_data(id, transformators, class = "well")
.srv_transform_teal_data(
id,
data,
transformators,
modules = NULL,
is_transform_failed = reactiveValues()
)
id |
( |
transformators |
( |
class |
|
data |
( |
modules |
|
is_transform_failed |
shiny.tag
reactive teal_data object
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.