teal_transform_module()This module calls teal_transform_module() sequentially by passing output from one step to the next.
Modules have error/warning handling feature and highlight containers when something goes wrong.
.ui_transform_teal_data(id, transformators, class = "well").srv_transform_teal_data(
id,
data,
transformators,
modules = NULL,
is_transform_failed = reactiveValues()
)
shiny.tag
reactive
teal_data object
(character(1)) shiny module instance id.
(list of teal_transform_module) decorator modules to apply sequentially
to data. Each transformator receives the output of the previous one as input.
(teal_data, teal_data_module, or reactive returning teal_data)
The data which application will depend on.