Learn R Programming

teal (version 1.2.1)

teal-package: teal: Interactive exploration of clinical trials data

Description

The teal package provides a shiny based framework for creating an interactive data analysis environment.

Arguments

Author

Maintainer: Dony Unardi unardid@gene.com

Authors:

Other contributors:

  • Nina Qi qi.ting@gene.com [reviewer]

  • Chendi Liao [reviewer]

  • F. Hoffmann-La Roche AG [copyright holder, funder]

  • Maximilian Mordig [contributor]

Details

To learn mode about the package, visit the project website or read the init() manual page.

See Also